@@ -8,7 +8,7 @@ from sqlalchemy_utils.functions import (
 )
 
 
-class TestRender(object):
+class TestRender:
 
     @pytest.fixture
     def User(self, Base):
@@ -39,7 +39,7 @@ class TestRender(object):
         assert 'WHERE user.id = 3' in text
 
     def test_render_statement_without_mapper(self, session):
-        statement = sa.select([sa.text('1')])
+        statement = sa.select(sa.text('1'))
         text = render_statement(statement, bind=session.bind)
 
         assert 'SELECT 1' in text
@@ -63,3 +63,15 @@ class TestRender(object):
 
         assert 'CREATE TABLE user' in text
         assert 'PRIMARY KEY' in text
+
+    def test_render_statement_hangul(self, User, session):
+        statement = User.__table__.select().where(
+            (User.id == 3)
+            & (User.name == "한글")
+        )
+        text = render_statement(statement, bind=session.bind)
+
+        assert "SELECT user.id, user.name" in text
+        assert "FROM user" in text
+        assert "user.id = 3" in text
+        assert "user.name = '한글'" in text
