@@ -1,7 +1,6 @@
 import pytest
 import sqlalchemy as sa
 
-from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.types import url
 
 
@@ -41,6 +40,6 @@ class TestURLType:
         assert isinstance(user.website, url.furl)
 
     def test_compilation(self, User, session):
-        query = sa.select(*_select_args(User.website))
+        query = sa.select(User.website)
         # the type should be cacheable and not throw exception
         session.execute(query)
